==> nextcloud-21.0.8p0.tgz: nextcloud/apps/files_external/l10n/fi.js <==
OC.L10N.register(
    "files_external",
    {
    "External storage" : "Erillinen tallennustila",
    "Personal" : "Henkilökohtainen",
    "System" : "Järjestelmä",
    "Grant access" : "Salli pääsy",
    "Error configuring OAuth1" : "Virhe OAuth1:n asetuksia tehdessä",
    "Please provide a valid app key and secret." : "Sovellusavain ja salaus ovat virheelliset",
    "Error configuring OAuth2" : "Virhe OAuth2:n asetuksia tehdessä",
    "Generate keys" : "Luo avaimet",
    "Error generating key pair" : "Virhe luotaessa avainparia",
    "All users. Type to select user or group." : "Kaikki käyttäjät. Kirjoita valitaksesi käyttäjän tai ryhmän.",
    "(Group)" : "(Ryhmä)",
    "Compatibility with Mac NFD encoding (slow)" : "Yhteensopivuus Mac NFD -enkoodauksen kanssa (hidas)",
    "Enable encryption" : "Käytä salausta",
    "Enable previews" : "Käytä esikatseluja",
    "Enable sharing" : "Käytä jakamista",
    "Check for changes" : "Tarkista muutokset",
    "Never" : "Ei koskaan",
    "Once every direct access" : "Kerran aina suoran käytön yhteydessä",
    "Read only" : "Vain luku",
    "Delete" : "Poista",
    "Admin defined" : "Ylläpitäjän määrittämä",
    "Are you sure you want to delete this external storage?" : "Haluatko varmasti poistaa tämän erillisen tallennustilan?",
    "Delete storage?" : "Poistetaanko tallennustila?",
    "Saved" : "Tallennettu",
    "Saving …" : "Tallennetaan…",
    "Save" : "Tallenna",
    "Empty response from the server" : "Tyhjä vastaus palvelimelta",
    "Couldn't access. Please log out and in again to activate this mount point" : "Käyttö ei onnistunut. Kirjaudu ulos ja takaisin sisään aktivoidaksesi tämän liitoskohdan",
    "Couldn't get the information from the remote server: {code} {type}" : "Tietojen saaminen etäpalvelimelta epäonnistui: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Erillisten liitospisteiden listauksen noutaminen epäonnistui: {type}",
    "There was an error with message: " : "Tapahtui virhe viestillä:",
    "External mount error" : "Erillisen liitosvirhe",
    "external-storage" : "external-storage",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Ei voitu noutaa listaa Windows-verkkoasemien liitoskohdista: tyhjä vastaus palvelimelta",
    "Please enter the credentials for the {mount} mount" : "Anna kirjautumistiedot liitokselle {mount}",
    "Username" : "Käyttäjätunnus",
    "Password" : "Salasana",
    "Credentials saved" : "Kirjautumistiedot tallennettu",
    "Credentials saving failed" : "Kirjautumistietojen tallentaminen epäonnistui",
    "Credentials required" : "Kirjautumistiedot vaaditaan",
    "Storage with ID \"%d\" not found" : "Tallennustilaa tunnisteella \"%d\" ei löytynyt",
    "Invalid backend or authentication mechanism class" : "Virheellinen tietovarasto tai tunnistautumismekanismin luokka",
    "Invalid mount point" : "Virheellinen liitoskohta",
    "Objectstore forbidden" : "Objektimuisti estetty",
    "Invalid storage backend \"%s\"" : "Virheellinen tallennustilan taustaosa \"%s\"",
    "Not permitted to use backend \"%s\"" : "Ei lupaa käyttää tietovarastoa \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Ei lupaa käyttää tunnistautumismekanismia  \"%s\"",
    "Unsatisfied backend parameters" : "Riittämättömät tietovaraston parametrit",
    "Unsatisfied authentication mechanism parameters" : "Riittämättömät tunnistautumismekanismin parametrit",
    "Insufficient data: %s" : "Puutteellinen data: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Tallennustila tunnisteella \"%d\" ei ole käyttäjän muokattavissa",
    "Access key" : "Pääsyavain",
    "Secret key" : "Salainen avain",
    "Builtin" : "Sisäänrakennettu",
    "None" : "Ei mitään",
    "OAuth1" : "OAuth1",
    "App key" : "Sovellusavain",
    "App secret" : "Sovellussalaisuus",
    "OAuth2" : "OAuth2",
    "Client ID" : "Asiakkaan tunniste",
    "Client secret" : "Asiakassalaisuus",
    "OpenStack v2" : "OpenStack v2",
    "Tenant name" : "Tenant nimi",
    "Identity endpoint URL" : "Määritä URL-päätepiste",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domaini",
    "Rackspace" : "Rackspace",
    "API key" : "API-avain",
    "Global credentials" : "Yleiset tunnistetiedot",
    "Log-in credentials, save in database" : "Kirjautumistiedot, tallennetaan tietokantaan",
    "Username and password" : "Käyttäjätunnus ja salasana",
    "Log-in credentials, save in session" : "Kirjautumistiedot, tallenna istuntoon",
    "Global credentials, user entered" : "Yleiset tunnistetiedot, käyttäjän syöttämät",
    "User entered, store in database" : "Käyttäjän antama, tallennettu tietokantaan",
    "RSA public key" : "Julkinen RSA-avain",
    "Public key" : "Julkinen avain",
    "RSA private key" : "Yksityinen RSA-avain",
    "Private key" : "Yksityinen avain",
    "Kerberos ticket" : "Kerberos-tiketti",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Isäntänimi",
    "Port" : "Portti",
    "Region" : "Alue",
    "Enable SSL" : "Käytä SSL:ää",
    "Enable Path Style" : "Aktivoi polun tyyli",
    "Legacy (v2) authentication" : "Vanha (v2) tunnistautuminen",
    "WebDAV" : "WebDAV",
    "URL" : "Verkko-osoite",
    "Remote subfolder" : "Etäalikansio",
    "Secure https://" : "Salattu https://",
    "FTP" : "FTP",
    "Host" : "Isäntä",
    "Secure ftps://" : "Salattu ftps://",
    "Local" : "Paikallinen",
    "Location" : "Sijainti",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Juurihakemisto",
    "SFTP with secret key login" : "SFTP salaisen avaimen kirjautumisella",
    "SMB/CIFS" : "SMB/CIFS",
    "Share" : "Jaa",
    "Show hidden files" : "Näytä piilotiedostot",
    "Verify ACL access when listing files" : "Vahvista ACL-pääsy tiedostoja listatessa",
    "Timeout" : "Aikakatkaisu",
    "Username as share" : "Käyttäjänimi jakona",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Palvelun nimi",
    "Request timeout (seconds)" : "Pyynnön aikakatkaisu (sekunneissa)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "cULR tuki PHPsta ei ole aktivoitu tai asennettu. Kohteen %s liittäminen ei ole mahdollista. Ota yhteyttä järjestelmänvalvojaan asentaaksesi puuttuvan osan.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "FTP tuki PHPsta ei ole aktivoitu tai asennettu. Kohteen %s liittäminen ei ole mahdollista. Ota yhteyttä järjestelmänvalvojaan asentaaksesi puuttuvan osan.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" on asentamatta. Kohdetta %2$s ei voi liittää. Pyydä järjestemän ylläpitäjää asentamaan puuttuvat osat.",
    "External storage support" : "Erillisen tallennustilan tuki",
    "Adds basic external storage support" : "Lisää perusmuotoisen tuen erillisille tallennustiloille",
    "No external storage configured or you don't have the permission to configure them" : "Erillistä tallennustilaa ei ole määritelty tai sinulla ei ole oikeuksia määrittää erillisiä tallennustiloja",
    "Name" : "Nimi",
    "Storage type" : "Tallennustilan tyyppi",
    "Scope" : "Näkyvyysalue",
    "Open documentation" : "Avaa dokumentaatio",
    "Folder name" : "Kansion nimi",
    "Authentication" : "Tunnistautuminen",
    "Configuration" : "Asetukset",
    "Available for" : "Saatavuus",
    "Click to recheck the configuration" : "Napsauta tarkistaaksesi uudelleen määritykset",
    "Add storage" : "Lisää tallennustila",
    "Advanced settings" : "Lisäasetukset",
    "Allow users to mount external storage" : "Salli käyttäjien liittää erillisiä tallennustiloja",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Yleisiä tunnistetietoja voidaan käyttää useisiin ulkoisiin tallennustiloihin tunnistautumiseen, joissa käytetään samoja tunnistetietoja.",
    "External storages" : "Erilliset tallennustilat",
    "(group)" : "(ryhmä)",
    "SMB / CIFS" : "SMB / CIFS",
    "SMB / CIFS using OC login" : "SMB / CIFS käyttäen OC-kirjautumista"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-22.2.1.tgz: nextcloud/apps/files_external/l10n/fi.js <==
OC.L10N.register(
    "files_external",
    {
    "External storage" : "Erillinen tallennustila",
    "Personal" : "Henkilökohtainen",
    "System" : "Järjestelmä",
    "Grant access" : "Salli pääsy",
    "Error configuring OAuth1" : "Virhe OAuth1:n asetuksia tehdessä",
    "Please provide a valid app key and secret." : "Sovellusavain ja salaus ovat virheelliset",
    "Error configuring OAuth2" : "Virhe OAuth2:n asetuksia tehdessä",
    "Generate keys" : "Luo avaimet",
    "Error generating key pair" : "Virhe luotaessa avainparia",
    "All users. Type to select user or group." : "Kaikki käyttäjät. Kirjoita valitaksesi käyttäjän tai ryhmän.",
    "(Group)" : "(Ryhmä)",
    "Compatibility with Mac NFD encoding (slow)" : "Yhteensopivuus Mac NFD -enkoodauksen kanssa (hidas)",
    "Enable encryption" : "Käytä salausta",
    "Enable previews" : "Käytä esikatseluja",
    "Enable sharing" : "Käytä jakamista",
    "Check for changes" : "Tarkista muutokset",
    "Never" : "Ei koskaan",
    "Once every direct access" : "Kerran aina suoran käytön yhteydessä",
    "Read only" : "Vain luku",
    "Delete" : "Poista",
    "Admin defined" : "Ylläpitäjän määrittämä",
    "Are you sure you want to delete this external storage?" : "Haluatko varmasti poistaa tämän erillisen tallennustilan?",
    "Delete storage?" : "Poistetaanko tallennustila?",
    "Saved" : "Tallennettu",
    "Saving …" : "Tallennetaan…",
    "Save" : "Tallenna",
    "Empty response from the server" : "Tyhjä vastaus palvelimelta",
    "Couldn't access. Please log out and in again to activate this mount point" : "Käyttö ei onnistunut. Kirjaudu ulos ja takaisin sisään aktivoidaksesi tämän liitoskohdan",
    "Couldn't get the information from the remote server: {code} {type}" : "Tietojen saaminen etäpalvelimelta epäonnistui: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Erillisten liitospisteiden listauksen noutaminen epäonnistui: {type}",
    "There was an error with message: " : "Tapahtui virhe viestillä:",
    "External mount error" : "Erillisen liitosvirhe",
    "external-storage" : "external-storage",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Ei voitu noutaa listaa Windows-verkkoasemien liitoskohdista: tyhjä vastaus palvelimelta",
    "Please enter the credentials for the {mount} mount" : "Anna kirjautumistiedot liitokselle {mount}",
    "Username" : "Käyttäjätunnus",
    "Password" : "Salasana",
    "Credentials saved" : "Kirjautumistiedot tallennettu",
    "Credentials saving failed" : "Kirjautumistietojen tallentaminen epäonnistui",
    "Credentials required" : "Kirjautumistiedot vaaditaan",
    "Storage with ID \"%d\" not found" : "Tallennustilaa tunnisteella \"%d\" ei löytynyt",
    "Invalid backend or authentication mechanism class" : "Virheellinen tietovarasto tai tunnistautumismekanismin luokka",
    "Invalid mount point" : "Virheellinen liitoskohta",
    "Objectstore forbidden" : "Objektimuisti estetty",
    "Invalid storage backend \"%s\"" : "Virheellinen tallennustilan taustaosa \"%s\"",
    "Not permitted to use backend \"%s\"" : "Ei lupaa käyttää tietovarastoa \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Ei lupaa käyttää tunnistautumismekanismia  \"%s\"",
    "Unsatisfied backend parameters" : "Riittämättömät tietovaraston parametrit",
    "Unsatisfied authentication mechanism parameters" : "Riittämättömät tunnistautumismekanismin parametrit",
    "Insufficient data: %s" : "Puutteellinen data: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Tallennustila tunnisteella \"%d\" ei ole käyttäjän muokattavissa",
    "Access key" : "Pääsyavain",
    "Secret key" : "Salainen avain",
    "Builtin" : "Sisäänrakennettu",
    "None" : "Ei mitään",
    "OAuth1" : "OAuth1",
    "App key" : "Sovellusavain",
    "App secret" : "Sovellussalaisuus",
    "OAuth2" : "OAuth2",
    "Client ID" : "Asiakkaan tunniste",
    "Client secret" : "Asiakassalaisuus",
    "OpenStack v2" : "OpenStack v2",
    "Tenant name" : "Tenant nimi",
    "Identity endpoint URL" : "Määritä URL-päätepiste",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domaini",
    "Rackspace" : "Rackspace",
    "API key" : "API-avain",
    "Global credentials" : "Yleiset tunnistetiedot",
    "Log-in credentials, save in database" : "Kirjautumistiedot, tallennetaan tietokantaan",
    "Username and password" : "Käyttäjätunnus ja salasana",
    "Log-in credentials, save in session" : "Kirjautumistiedot, tallenna istuntoon",
    "Global credentials, user entered" : "Yleiset tunnistetiedot, käyttäjän syöttämät",
    "User entered, store in database" : "Käyttäjän antama, tallennettu tietokantaan",
    "RSA public key" : "Julkinen RSA-avain",
    "Public key" : "Julkinen avain",
    "RSA private key" : "Yksityinen RSA-avain",
    "Private key" : "Yksityinen avain",
    "Kerberos ticket" : "Kerberos-tiketti",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Isäntänimi",
    "Port" : "Portti",
    "Region" : "Alue",
    "Enable SSL" : "Käytä SSL:ää",
    "Enable Path Style" : "Aktivoi polun tyyli",
    "Legacy (v2) authentication" : "Vanha (v2) tunnistautuminen",
    "WebDAV" : "WebDAV",
    "URL" : "Verkko-osoite",
    "Remote subfolder" : "Etäalikansio",
    "Secure https://" : "Salattu https://",
    "FTP" : "FTP",
    "Host" : "Isäntä",
    "Secure ftps://" : "Salattu ftps://",
    "Local" : "Paikallinen",
    "Location" : "Sijainti",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Juurihakemisto",
    "SFTP with secret key login" : "SFTP salaisen avaimen kirjautumisella",
    "SMB/CIFS" : "SMB/CIFS",
    "Share" : "Jaa",
    "Show hidden files" : "Näytä piilotiedostot",
    "Timeout" : "Aikakatkaisu",
    "Username as share" : "Käyttäjänimi jakona",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Palvelun nimi",
    "Request timeout (seconds)" : "Pyynnön aikakatkaisu (sekunneissa)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "cULR tuki PHPsta ei ole aktivoitu tai asennettu. Kohteen %s liittäminen ei ole mahdollista. Ota yhteyttä järjestelmänvalvojaan asentaaksesi puuttuvan osan.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "FTP tuki PHPsta ei ole aktivoitu tai asennettu. Kohteen %s liittäminen ei ole mahdollista. Ota yhteyttä järjestelmänvalvojaan asentaaksesi puuttuvan osan.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" on asentamatta. Kohdetta %2$s ei voi liittää. Pyydä järjestemän ylläpitäjää asentamaan puuttuvat osat.",
    "External storage support" : "Erillisen tallennustilan tuki",
    "Adds basic external storage support" : "Lisää perusmuotoisen tuen erillisille tallennustiloille",
    "No external storage configured or you don't have the permission to configure them" : "Erillistä tallennustilaa ei ole määritelty tai sinulla ei ole oikeuksia määrittää erillisiä tallennustiloja",
    "Name" : "Nimi",
    "Storage type" : "Tallennustilan tyyppi",
    "Scope" : "Näkyvyysalue",
    "Open documentation" : "Avaa dokumentaatio",
    "Folder name" : "Kansion nimi",
    "Authentication" : "Tunnistautuminen",
    "Configuration" : "Asetukset",
    "Available for" : "Saatavuus",
    "Click to recheck the configuration" : "Napsauta tarkistaaksesi uudelleen määritykset",
    "Add storage" : "Lisää tallennustila",
    "Advanced settings" : "Lisäasetukset",
    "Allow users to mount external storage" : "Salli käyttäjien liittää erillisiä tallennustiloja",
    "External storages" : "Erilliset tallennustilat",
    "(group)" : "(ryhmä)",
    "SMB / CIFS" : "SMB / CIFS",
    "SMB / CIFS using OC login" : "SMB / CIFS käyttäen OC-kirjautumista",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Yleisiä tunnistetietoja voidaan käyttää useisiin ulkoisiin tallennustiloihin tunnistautumiseen, joissa käytetään samoja tunnistetietoja."
},
"nplurals=2; plural=(n != 1);");
